// SPDX-License-Identifier: LGPL-2.1-or-later

#ifndef LIBJAYLINK_VERSION_H
#define LIBJAYLINK_VERSION_H

/**
 * @file
 *
 * Package and library version macros.
 */

/** Major version number of the libjaylink package. */
#define JAYLINK_VERSION_PACKAGE_MAJOR		0

/** Minor version number of the libjaylink package. */
#define JAYLINK_VERSION_PACKAGE_MINOR		5

/** Micro version number of the libjaylink package. */
#define JAYLINK_VERSION_PACKAGE_MICRO		0

/** Version number string of the libjaylink package. */
#define JAYLINK_VERSION_PACKAGE_STRING		"0.5.0"

/** <i>Current</i> version number of the libjaylink libtool interface. */
#define JAYLINK_VERSION_LIBRARY_CURRENT		2

/** <i>Revision</i> version number of the libjaylink libtool interface. */
#define JAYLINK_VERSION_LIBRARY_REVISION	2

/** <i>Age</i> version number of the libjaylink libtool interface. */
#define JAYLINK_VERSION_LIBRARY_AGE		2

/** Version number string of the libjaylink libtool interface. */
#define JAYLINK_VERSION_LIBRARY_STRING		"0.2.2"

#endif /* LIBJAYLINK_VERSION_H */
